Package: kedd
Version: 1.0.4
License: GPL (>= 2)
Description: Smoothing techniques and computing bandwidth selectors of the nth derivative of a probability density for one-dimensional data (described in Arsalane Chouaib Guidoum (2020) <arXiv:2012.06102> [stat.CO]).
Title: Kernel Estimator and Bandwidth Selection for Density and Its
        Derivatives
Authors@R: c(
  person("Iago", "Giné-Vázquez", role = c("cre"), 
                                 email = "iago.gin-vaz@protonmail.com", 
                                 comment = c(ORCID = "0000-0002-6725-2638")),
  person("Arsalane Chouaib", "Guidoum", role = "aut"))
Date: 2024-01-27
Depends: R (>= 2.15.0)
Suggests: nor1mix, ks, sm, locfit, orthopolynom
URL: https://gitlab.com/iagogv/kedd
BugReports: https://gitlab.com/iagogv/kedd/-/issues
Encoding: UTF-8
LazyData: yes
NeedsCompilation: no
Type: Package
Classification/MSC: 62G05, 62G07, 65D10, 68N15
Packaged: 2024-01-30 23:24:45 UTC; iago
Author: Iago Giné-Vázquez [cre] (<https://orcid.org/0000-0002-6725-2638>),
  Arsalane Chouaib Guidoum [aut]
Maintainer: Iago Giné-Vázquez <iago.gin-vaz@protonmail.com>
Repository: CRAN
Date/Publication: 2024-02-01 11:00:02 UTC
Built: R 4.2.3; ; 2024-02-01 15:45:13 UTC; unix
