**kedd**


[![CRAN status](https://badges.cranchecks.info/summary/kedd.svg)](https://cran.r-project.org/web/checks/check_results_kedd.html)

The `kedd` package provides additional smoothing techniques to the [R](https://www.r-project.org/) statistical system. Although various packages hosted by the [Comprehensive R Archive Network (CRAN)](https://cran.r-project.org/) provide useful functions to nonparametric statistics, `kedd` aims to serve as a central location for, more specifically, nonparametric functions and datasets. 

The current features set of the package can be split in four main categories: 
- compute the convolutions and derivatives of a kernel function;
- compute the kernel estimators for a probability density function and its derivatives; 
- computing the bandwidth selectors with different methods; 
- displaying the kernel estimators and selection functions of the bandwidth. 


